# TemplateExtraction

Extracts data using from a templated component of a request

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**template_name** | **str** | The name of the template item. E.g. &#x60;guid&#x60; in &#x60;/collection/{guid}&#x60;. Different locations in the request can have the same name.  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


